@@ -21,10 +21,12 @@
 #include "activitymodule.h"
 
 
-ActivityModule::ActivityModule(GlobalObject *globalObject,
+ActivityModule::ActivityModule(ActivityHandler *handler,
+                               GlobalObject *globalObject,
                                QWidget *parent) : QWidget(parent)
 {
     this->globalObj = globalObject;
+    this->activityHandler = handler;
 
     this->dataFile = new DataFile(globalObj->getDataDirectory()
                                   + "/activities.axb",
@@ -91,9 +93,9 @@ ActivityModule::ActivityModule(GlobalObject *globalObject,
     maxDateEdit->setDisplayFormat("dd MMMM");
 
     this->minDurationSpinbox = new QSpinBox(this);
-    minDurationSpinbox->setRange(1, 300);
+    minDurationSpinbox->setRange(1, 1440); // Up to 1440 min, 24h
     this->maxDurationSpinbox = new QSpinBox(this);
-    maxDurationSpinbox->setRange(1, 300);
+    maxDurationSpinbox->setRange(1, 1440);
     maxDurationSpinbox->setSuffix(" " + tr("minutes"));
 
     this->statusTypeCombobox = new QComboBox(this);
@@ -103,6 +105,9 @@ ActivityModule::ActivityModule(GlobalObject *globalObject,
     statusTypeCombobox->addItem(tr("Extended Away"));
     statusTypeCombobox->addItem(tr("Do not Disturb"));
 
+    this->statusMessagesListWidget = new StringListWidget(false, this);
+
+
     this->availabilitySpinbox = new QSpinBox(this);
     availabilitySpinbox->setRange(0, 100);
     availabilitySpinbox->setValue(50);
@@ -116,21 +121,33 @@ ActivityModule::ActivityModule(GlobalObject *globalObject,
     maxReactionSpinbox->setSuffix(" " + tr("seconds"));
 
 
-    this->descriptionListWidget = new StringListWidget(this);
+    this->descriptionListWidget = new StringListWidget(false, this);
 
-    this->msgBeforeListWidget = new StringListWidget(this);
+    this->msgBeforeListWidget = new StringListWidget(false, this);
 
-    this->msgAfterListWidget = new StringListWidget(this);
+    this->msgAfterListWidget = new StringListWidget(false, this);
 
 
-    // Send messsages to: all rooms/some rooms/few rooms + active private conversations
+    // Send messsages to: all rooms/some rooms/few rooms/specific jids + active private conversations
     this->msgToRoomsCombobox = new QComboBox(this);
-    msgToRoomsCombobox->addItem(tr("All rooms"));
-    msgToRoomsCombobox->addItem(tr("Several rooms"));
-    msgToRoomsCombobox->addItem(tr("A few rooms"));
+    msgToRoomsCombobox->addItem(tr("All rooms")     + " [Not implemented]"); // tmp/FIXME
+    msgToRoomsCombobox->addItem(tr("Several rooms") + " [Not implemented]"); // tmp/FIXME
+    msgToRoomsCombobox->addItem(tr("A few rooms")   + " [Not implemented]"); // tmp/FIXME
+    msgToRoomsCombobox->addItem(tr("Specific JIDs") + " [Only First JID]");  // tmp/FIXME
+    connect(msgToRoomsCombobox, SIGNAL(currentIndexChanged(int)),
+            this, SLOT(onRecipientsTypeChanged(int)));
+
+
+    // FIXME? Probably better to use a StringListWidget, and put it below
+    this->specificJidsLineEdit = new QLineEdit(this);
+    specificJidsLineEdit->setToolTip(tr("List of room or user addresses, "
+                                        "separated by space"));
+    specificJidsLineEdit->hide();
+
 
     this->msgToChatsCheckbox = new QCheckBox(tr("Also to active private chats"),
                                              this);
+    msgToChatsCheckbox->setDisabled(true); // TMP FIXME: Until the setting is implemented
 
 
     this->saveActivityButton = new QPushButton(QIcon::fromTheme("document-save",
@@ -164,15 +181,16 @@ ActivityModule::ActivityModule(GlobalObject *globalObject,
     durationLayout->addSpacing(8);
     durationLayout->addWidget(maxDurationSpinbox);
 
-    this->msgRecipientsLayout = new QHBoxLayout();
-    msgRecipientsLayout->addWidget(msgToRoomsCombobox);
-    msgRecipientsLayout->addWidget(msgToChatsCheckbox);
-
     this->reactionLayout = new QHBoxLayout();
     reactionLayout->addWidget(minReactionSpinbox);
     reactionLayout->addSpacing(8);
     reactionLayout->addWidget(maxReactionSpinbox);
 
+    this->msgRecipientsLayout = new QHBoxLayout();
+    msgRecipientsLayout->addWidget(msgToRoomsCombobox);
+    msgRecipientsLayout->addWidget(specificJidsLineEdit);
+    msgRecipientsLayout->addWidget(msgToChatsCheckbox);
+
 
     this->formLayout = new QFormLayout();
     formLayout->addRow(tr("Name"),                  nameLineEdit);
@@ -182,6 +200,7 @@ ActivityModule::ActivityModule(GlobalObject *globalObject,
     formLayout->addRow(tr("Date Range"),            dateLayout);
     formLayout->addRow(tr("Duration"),              durationLayout);
     formLayout->addRow(tr("Set Status Type"),       statusTypeCombobox);
+    formLayout->addRow(tr("Status Messages"),       statusMessagesListWidget);
     formLayout->addRow(tr("Availability"),          availabilitySpinbox);
     formLayout->addRow(tr("Reaction Time"),         reactionLayout);
     formLayout->addRow(tr("Descriptions"),          descriptionListWidget);
@@ -190,23 +209,29 @@ ActivityModule::ActivityModule(GlobalObject *globalObject,
     formLayout->addRow(tr("Send Messages To"),      msgRecipientsLayout);
 
 
-    this->rightLayout = new QVBoxLayout();
-    rightLayout->addLayout(formLayout);
-    rightLayout->addStretch();
-    rightLayout->addWidget(saveActivityButton, 0, Qt::AlignRight);
-
     this->rightWidget = new QWidget(this);
-    this->rightWidget->setLayout(rightLayout);
+    this->rightWidget->setLayout(formLayout);
 
+    this->rightScrollArea = new QScrollArea(this);
+    rightScrollArea->setContentsMargins(1, 1, 1, 1);
+    rightScrollArea->setFrameStyle(QFrame::Box | QFrame::Raised);
+    rightScrollArea->setWidgetResizable(true);
+    rightScrollArea->setWidget(rightWidget);
+
+    this->rightLayout = new QVBoxLayout();
+    rightLayout->addWidget(rightScrollArea);
+    rightLayout->addWidget(saveActivityButton, 0, Qt::AlignRight);
 
     this->mainLayout = new QHBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addLayout(leftLayout,  1);
-    mainLayout->addWidget(rightWidget, 4);
+    mainLayout->addLayout(rightLayout, 4);
     this->setLayout(mainLayout);
 
 
-    this->rightWidget->setDisabled(true);
+    this->removeActivityButton->setDisabled(true);
+    this->rightScrollArea->setDisabled(true);
+    this->saveActivityButton->setDisabled(true);
 
     this->loadActivities();
 
@@ -242,27 +267,32 @@ void ActivityModule::loadActivities()
         item->setData(Qt::UserRole + 7,  map.value("minDuration"));
         item->setData(Qt::UserRole + 8,  map.value("maxDuration"));
         item->setData(Qt::UserRole + 9,  map.value("statusType"));
-        item->setData(Qt::UserRole + 10, map.value("availability"));
-        item->setData(Qt::UserRole + 11, map.value("minReaction"));
-        item->setData(Qt::UserRole + 12, map.value("maxReaction"));
-        item->setData(Qt::UserRole + 13, map.value("descriptions"));
-        item->setData(Qt::UserRole + 14, map.value("msgBefore"));
-        item->setData(Qt::UserRole + 15, map.value("msgAfter"));
-        item->setData(Qt::UserRole + 16, map.value("msgToRooms"));
-        item->setData(Qt::UserRole + 17, map.value("msgToChats"));
+        item->setData(Qt::UserRole + 10, map.value("statusMessages"));
+        item->setData(Qt::UserRole + 11, map.value("availability"));
+        item->setData(Qt::UserRole + 12, map.value("minReaction"));
+        item->setData(Qt::UserRole + 13, map.value("maxReaction"));
+        item->setData(Qt::UserRole + 14, map.value("descriptions"));
+        item->setData(Qt::UserRole + 15, map.value("msgBefore"));
+        item->setData(Qt::UserRole + 16, map.value("msgAfter"));
+        item->setData(Qt::UserRole + 17, map.value("msgToRooms"));
+        item->setData(Qt::UserRole + 18, map.value("specificJids"));
+        item->setData(Qt::UserRole + 19, map.value("msgToChats"));
 
 
         this->activityListWidget->addItem(item);
     }
 
-    this->globalObj->addToLog(tr("Loaded %1 activities.")
-                              .arg(activityDataList.length()));
+    this->activityHandler->setActivityData(activityDataList);
+
+    this->globalObj->addToLog(tr("Loaded %Ln activities.",
+                                 "",
+                                 activityDataList.length()));
 }
 
 
 bool ActivityModule::validateActivity()
 {
-    return true; /////// tmp
+    return true; /////// tmp FIXME
 }
 
 
@@ -279,6 +309,12 @@ void ActivityModule::onNameChanged(QString newName)
 }
 
 
+void ActivityModule::onRecipientsTypeChanged(int option)
+{
+    this->specificJidsLineEdit->setVisible(option == 3); // Visible only for Specific JIDs option
+}
+
+
 void ActivityModule::addActivity()
 {
     QListWidgetItem *item = new QListWidgetItem("-- "
@@ -306,17 +342,25 @@ void ActivityModule::addActivity()
     // Status type
     item->setData(Qt::UserRole + 9, 0);
 
+    // Nothing to set here for the status messages list (UR + 10)
+
     // Availability %
-    item->setData(Qt::UserRole + 10, 50);
+    item->setData(Qt::UserRole + 11, 50);
 
     // Reaction time range
-    item->setData(Qt::UserRole + 11, 1);
-    item->setData(Qt::UserRole + 12, 10);
+    item->setData(Qt::UserRole + 12, 1);
+    item->setData(Qt::UserRole + 13, 10);
 
-    // Nothing to set here for the lists (UR + 13, 14, 15)
+    // Nothing to set here for the lists (UR + 14, 15, 16)
 
-    item->setData(Qt::UserRole + 16, 0);
-    item->setData(Qt::UserRole + 17, true);
+    // Send messages to...
+    item->setData(Qt::UserRole + 17, 0);
+
+    // Specific recipient JIDs
+    item->setData(Qt::UserRole + 18, "");
+
+    // Messages also to active private chats
+    item->setData(Qt::UserRole + 19, true);
 
 
     this->activityListWidget->addItem(item);
@@ -341,7 +385,9 @@ void ActivityModule::removeActivity()
 
     if (activityListWidget->count() == 0) // No activities left
     {
-        this->rightWidget->setDisabled(true);
+        this->removeActivityButton->setDisabled(true);
+        this->rightScrollArea->setDisabled(true);
+        this->saveActivityButton->setDisabled(true);
     }
 }
 
@@ -368,26 +414,30 @@ void ActivityModule::onActivitySelected(int row)
     this->maxDurationSpinbox->setValue(item->data(Qt::UserRole + 8).toInt());
 
     this->statusTypeCombobox->setCurrentIndex(item->data(Qt::UserRole + 9).toInt());
+    this->statusMessagesListWidget->clearList();
+    this->statusMessagesListWidget->addStringsToList(item->data(Qt::UserRole + 10).toStringList());
 
-    this->availabilitySpinbox->setValue(item->data(Qt::UserRole + 10).toInt());
+    this->availabilitySpinbox->setValue(item->data(Qt::UserRole + 11).toInt());
 
-    this->minReactionSpinbox->setValue(item->data(Qt::UserRole + 11).toInt());
-    this->maxReactionSpinbox->setValue(item->data(Qt::UserRole + 12).toInt());
+    this->minReactionSpinbox->setValue(item->data(Qt::UserRole + 12).toInt());
+    this->maxReactionSpinbox->setValue(item->data(Qt::UserRole + 13).toInt());
 
     this->descriptionListWidget->clearList();
-    this->descriptionListWidget->addStringsToList(item->data(Qt::UserRole + 13).toStringList());
+    this->descriptionListWidget->addStringsToList(item->data(Qt::UserRole + 14).toStringList());
 
     this->msgBeforeListWidget->clearList();
-    this->msgBeforeListWidget->addStringsToList(item->data(Qt::UserRole + 14).toStringList());
+    this->msgBeforeListWidget->addStringsToList(item->data(Qt::UserRole + 15).toStringList());
 
     this->msgAfterListWidget->clearList();
-    this->msgAfterListWidget->addStringsToList(item->data(Qt::UserRole + 15).toStringList());
+    this->msgAfterListWidget->addStringsToList(item->data(Qt::UserRole + 16).toStringList());
 
-    this->msgToRoomsCombobox->setCurrentIndex(item->data(Qt::UserRole + 16).toInt());
-    this->msgToChatsCheckbox->setChecked(item->data(Qt::UserRole + 17).toBool());
+    this->msgToRoomsCombobox->setCurrentIndex(item->data(Qt::UserRole + 17).toInt());
+    this->specificJidsLineEdit->setText(item->data(Qt::UserRole + 18).toString());
+    this->msgToChatsCheckbox->setChecked(item->data(Qt::UserRole + 19).toBool());
 
 
-    this->rightWidget->setEnabled(true);
+    this->removeActivityButton->setEnabled(true);
+    this->rightScrollArea->setEnabled(true);
 }
 
 
@@ -437,18 +487,20 @@ void ActivityModule::saveActivity()
     item->setData(Qt::UserRole + 8, maxDurationSpinbox->value());
 
     item->setData(Qt::UserRole + 9, statusTypeCombobox->currentIndex());
+    item->setData(Qt::UserRole + 10, statusMessagesListWidget->getStringsFromList());
 
-    item->setData(Qt::UserRole + 10, availabilitySpinbox->value());
+    item->setData(Qt::UserRole + 11, availabilitySpinbox->value());
 
-    item->setData(Qt::UserRole + 11, minReactionSpinbox->value());
-    item->setData(Qt::UserRole + 12, maxReactionSpinbox->value());
+    item->setData(Qt::UserRole + 12, minReactionSpinbox->value());
+    item->setData(Qt::UserRole + 13, maxReactionSpinbox->value());
 
-    item->setData(Qt::UserRole + 13, descriptionListWidget->getStringsFromList());
-    item->setData(Qt::UserRole + 14, msgBeforeListWidget->getStringsFromList());
-    item->setData(Qt::UserRole + 15, msgAfterListWidget->getStringsFromList());
+    item->setData(Qt::UserRole + 14, descriptionListWidget->getStringsFromList());
+    item->setData(Qt::UserRole + 15, msgBeforeListWidget->getStringsFromList());
+    item->setData(Qt::UserRole + 16, msgAfterListWidget->getStringsFromList());
 
-    item->setData(Qt::UserRole + 16, msgToRoomsCombobox->currentIndex());
-    item->setData(Qt::UserRole + 17, msgToChatsCheckbox->isChecked());
+    item->setData(Qt::UserRole + 17, msgToRoomsCombobox->currentIndex());
+    item->setData(Qt::UserRole + 18, specificJidsLineEdit->text());
+    item->setData(Qt::UserRole + 19, msgToChatsCheckbox->isChecked());
 
 
 
@@ -465,32 +517,35 @@ void ActivityModule::syncActivities()
         QListWidgetItem *item = activityListWidget->item(counter);
 
         QVariantMap activityMap;
-        activityMap.insert("name",          item->data(Qt::UserRole));
-        activityMap.insert("timesPerDay",   item->data(Qt::UserRole + 1));
-        activityMap.insert("probability",   item->data(Qt::UserRole + 2));
-        activityMap.insert("minTime",       item->data(Qt::UserRole + 3));
-        activityMap.insert("maxTime",       item->data(Qt::UserRole + 4));
-        activityMap.insert("minDate",       item->data(Qt::UserRole + 5));
-        activityMap.insert("maxDate",       item->data(Qt::UserRole + 6));
-        activityMap.insert("minDuration",   item->data(Qt::UserRole + 7));
-        activityMap.insert("maxDuration",   item->data(Qt::UserRole + 8));
-        activityMap.insert("statusType",    item->data(Qt::UserRole + 9));
-        activityMap.insert("availability",  item->data(Qt::UserRole + 10));
-        activityMap.insert("minReaction",   item->data(Qt::UserRole + 11));
-        activityMap.insert("maxReaction",   item->data(Qt::UserRole + 12));
-        activityMap.insert("descriptions",  item->data(Qt::UserRole + 13));
-        activityMap.insert("msgBefore",     item->data(Qt::UserRole + 14));
-        activityMap.insert("msgAfter",      item->data(Qt::UserRole + 15));
-        activityMap.insert("msgToRooms",    item->data(Qt::UserRole + 16));
-        activityMap.insert("msgToChats",    item->data(Qt::UserRole + 17));
+        activityMap.insert("name",           item->data(Qt::UserRole));
+        activityMap.insert("timesPerDay",    item->data(Qt::UserRole + 1));
+        activityMap.insert("probability",    item->data(Qt::UserRole + 2));
+        activityMap.insert("minTime",        item->data(Qt::UserRole + 3));
+        activityMap.insert("maxTime",        item->data(Qt::UserRole + 4));
+        activityMap.insert("minDate",        item->data(Qt::UserRole + 5));
+        activityMap.insert("maxDate",        item->data(Qt::UserRole + 6));
+        activityMap.insert("minDuration",    item->data(Qt::UserRole + 7));
+        activityMap.insert("maxDuration",    item->data(Qt::UserRole + 8));
+        activityMap.insert("statusType",     item->data(Qt::UserRole + 9));
+        activityMap.insert("statusMessages", item->data(Qt::UserRole + 10));
+        activityMap.insert("availability",   item->data(Qt::UserRole + 11));
+        activityMap.insert("minReaction",    item->data(Qt::UserRole + 12));
+        activityMap.insert("maxReaction",    item->data(Qt::UserRole + 13));
+        activityMap.insert("descriptions",   item->data(Qt::UserRole + 14));
+        activityMap.insert("msgBefore",      item->data(Qt::UserRole + 15));
+        activityMap.insert("msgAfter",       item->data(Qt::UserRole + 16));
+        activityMap.insert("msgToRooms",     item->data(Qt::UserRole + 17));
+        activityMap.insert("specificJids",   item->data(Qt::UserRole + 18));
+        activityMap.insert("msgToChats",     item->data(Qt::UserRole + 19));
 
 
         activityDataList.append(activityMap);
     }
 
+    this->activityHandler->setActivityData(activityDataList);
     this->dataFile->saveData(activityDataList);
 
-    this->globalObj->addToLog(tr("Saved %1 activities.")
-                              .arg(activityDataList.length()));
+    this->globalObj->addToLog(tr("Saved %Ln activities.", "",
+                                 activityDataList.length()));
 }
 
