@@ -156,6 +156,13 @@ void ChatWidget::appendMessage(QXmppMessage message)
             return;
         }
 
+        // Ignore completely empty messages (from ChatState changes, etc)
+        // FIXME: In the future, show these state changes somewhere else
+        if (body.isEmpty())
+        {
+            return;
+        }
+
         nick = Helpers::nickFromRoomJid(message.from());
 
         if (nick == this->muc->nickName())
