@@ -77,19 +77,49 @@ CommandModule::CommandModule(CommandHandler *handler,
                                                "'it' refers to a command"));
 
     this->typeCombobox = new QComboBox(this);
-    typeCombobox->addItem(tr("Static Message"));
-    typeCombobox->addItem(tr("Random Sentence"));
-    typeCombobox->addItem(tr("Random Line from Text File") + " (UTF-8)");
-    typeCombobox->addItem(tr("Keyword"));
-    typeCombobox->addItem(tr("Run Program"));
-    typeCombobox->addItem(tr("Alias for another command"));
+    typeCombobox->addItem(tr("Static Message"),
+                          tr("Just enter a single sentence."));
+    typeCombobox->addItem(tr("Random Sentence"),
+                          tr("Add as many sentences as you want.\n"
+                             "One of them will be selected at random as "
+                             "a reply."));
+    typeCombobox->addItem(tr("Random Line from Text File") + " (UTF-8)",
+                          tr("A random line from the chosen file will be used "
+                             "as a reply.\n"
+                             "File encoding should be UTF-8."));
+    typeCombobox->addItem(tr("Keyword-based Message"),
+                          tr("Add keywords to the list, then enter the "
+                             "corresponding definition for each keyword on "
+                             "the other side."));
+    typeCombobox->addItem(tr("Run Program"),
+                          tr("Enter a command to be run, with any needed "
+                             "parameters.\n"
+                             "The reply will be the console output of the "
+                             "program, unless you specify an output pattern, "
+                             "and don't include the %output% variable "
+                             "somewhere in it.",
+                             "Don't translate %output%!"));
+    typeCombobox->addItem(tr("Alias for another command"),
+                          tr("Enter the original command that should be run "
+                             "when this alias is used."));
+
+    QFont helpFont;
+    helpFont.setItalic(true);
+
+    this->typeHelpLabel = new QLabel(this);
+    typeHelpLabel->setFont(helpFont);
+    typeHelpLabel->setWordWrap(true);
+    typeHelpLabel->setContentsMargins(16, 1, 16, 1);
+    typeHelpLabel->setSizePolicy(QSizePolicy::MinimumExpanding,
+                                 QSizePolicy::Minimum);
+
     connect(typeCombobox, SIGNAL(currentIndexChanged(int)),
             this, SLOT(onTypeChanged(int)));
 
 
     this->staticLineEdit = new QLineEdit(this);
 
-    this->randomListWidget = new StringListWidget(this);
+    this->randomListWidget = new StringListWidget(false, this);
 
     this->filenameLabel = new QLabel(this);
     this->filenameButton = new QPushButton(QIcon::fromTheme("document-open",
@@ -103,7 +133,8 @@ CommandModule::CommandModule(CommandHandler *handler,
     filenameLayout->addWidget(filenameButton, 0);
 
 
-    // Init Keyword-based widget here -- TODO
+    this->keywordListWidget = new StringListWidget(true, this);
+    keywordListWidget->setLowercaseItems(true);
 
 
     this->programLineEdit = new QLineEdit(this);
@@ -112,8 +143,8 @@ CommandModule::CommandModule(CommandHandler *handler,
 
 
     this->outputLineEdit = new QLineEdit(this);
-    this->outputLineEdit->setPlaceholderText(tr("Such as: "
-                                                "[REPLY] %line% %output%"));
+    this->outputLineEdit->setPlaceholderText(tr("Optional, like: "
+                                                "[RESULT] %line% %output%"));
 
     this->privateReplyCheckbox = new QCheckBox(this);
 
@@ -141,19 +172,20 @@ CommandModule::CommandModule(CommandHandler *handler,
     typeLayout->addWidget(staticLineEdit);
     typeLayout->addWidget(randomListWidget);
     typeLayout->addLayout(filenameLayout);
-    // typeLayout->addWidget(keyword list widget); // TODO
+    typeLayout->addWidget(keywordListWidget);
     typeLayout->addWidget(programLineEdit);
     typeLayout->addWidget(aliasLineEdit);
 
 
     this->formLayout = new QFormLayout();
-    formLayout->addRow(tr("Command"),           triggerLineEdit);
-    formLayout->addRow(tr("Help Text"),         helpLineEdit);
-    formLayout->addRow(tr("Access Level"),      accessLevelSpinbox);
-    formLayout->addRow(tr("Type"),              typeCombobox);
+    formLayout->addRow(tr("Command"),         triggerLineEdit);
+    formLayout->addRow(tr("Help Text"),       helpLineEdit);
+    formLayout->addRow(tr("Access Level"),    accessLevelSpinbox);
+    formLayout->addRow(tr("Type"),            typeCombobox);
+    formLayout->addWidget(typeHelpLabel);
     formLayout->addRow("", typeLayout);
-    formLayout->addRow(tr("Output Pattern"),    outputLineEdit);
-    formLayout->addRow(tr("Reply In Private"),  privateReplyCheckbox);
+    formLayout->addRow(tr("Output Pattern"),  outputLineEdit);
+    formLayout->addRow(tr("Private Reply"),   privateReplyCheckbox);
 
 
     this->rightLayout = new QVBoxLayout();
@@ -173,6 +205,7 @@ CommandModule::CommandModule(CommandHandler *handler,
 
 
     this->onTypeChanged(0); // Select first type to show its extra widget
+    this->removeCommandButton->setDisabled(true);
     this->rightWidget->setDisabled(true);
 
     this->loadCommands();
@@ -228,7 +261,8 @@ void CommandModule::loadCommands()
         }
         else if (commandType == 3)
         {
-            // Keyword
+            item->setData(Qt::UserRole + 4,
+                          map.value("keywords"));
         }
         else if (commandType == 4)
         {
@@ -249,8 +283,9 @@ void CommandModule::loadCommands()
 
     this->commandHandler->setCommandData(commandDataList);
 
-    this->globalObj->addToLog(tr("Loaded %1 commands.")
-                              .arg(commandDataList.length()));
+    this->globalObj->addToLog(tr("Loaded %Ln command(s).",
+                                 "",
+                                 commandDataList.length()));
 }
 
 
@@ -285,7 +320,13 @@ bool CommandModule::validateCommand(int commandType)
     }
     else if (commandType == 3)
     {
-        // Keyword
+        if (this->keywordListWidget->getStringsFromList().length() == 0)
+        {
+            errorMessage = tr("There are no keywords in the list.");
+            this->keywordListWidget->setFocus();
+        }
+
+        // TODO -- FIXME: Check that each keyword has content
     }
     else if (commandType == 4)
     {
@@ -303,6 +344,12 @@ bool CommandModule::validateCommand(int commandType)
                               "will execute.");
             this->aliasLineEdit->setFocus();
         }
+        else if (this->aliasLineEdit->text().trimmed()
+              == this->triggerLineEdit->text().trimmed())
+        {
+            errorMessage = tr("A command can't be an alias of itself.");
+            this->aliasLineEdit->setFocus();
+        }
     }
 
 
@@ -381,6 +428,7 @@ void CommandModule::removeCommand()
 
     if (commandListWidget->count() == 0) // No commands left
     {
+        this->removeCommandButton->setDisabled(true);
         this->rightWidget->setDisabled(true);
     }
 }
@@ -404,6 +452,7 @@ void CommandModule::onCommandSelected(int row)
     this->randomListWidget->clearList();
     this->filenameLabel->setText("[" + tr("No file selected") + "]");
     this->textFilename.clear();
+    this->keywordListWidget->clearList();
     this->programLineEdit->clear();
     this->aliasLineEdit->clear();
 
@@ -425,7 +474,8 @@ void CommandModule::onCommandSelected(int row)
     }
     else if (commandType == 3)
     {
-        // Keyword
+        QVariantMap stringMap = item->data(Qt::UserRole + 4).toMap();
+        this->keywordListWidget->addItemsToList(stringMap);
     }
     else if (commandType == 4)
     {
@@ -441,17 +491,21 @@ void CommandModule::onCommandSelected(int row)
     this->privateReplyCheckbox->setChecked(item->data(Qt::UserRole + 6).toBool());
 
 
+    this->removeCommandButton->setEnabled(true);
     this->rightWidget->setEnabled(true);
 }
 
 
 void CommandModule::onTypeChanged(int commandType)
 {
+    // Show the informational text for this command type
+    this->typeHelpLabel->setText(typeCombobox->itemData(commandType).toString());
+
     this->staticLineEdit->hide();
     this->randomListWidget->hide();
     this->filenameLabel->hide();
     this->filenameButton->hide();
-
+    this->keywordListWidget->hide();
     this->programLineEdit->hide();
     this->aliasLineEdit->hide();
 
@@ -471,7 +525,7 @@ void CommandModule::onTypeChanged(int commandType)
     }
     else if (commandType == 3)
     {
-        // Keyword
+        this->keywordListWidget->show();
     }
     else if (commandType == 4)
     {
@@ -542,7 +596,8 @@ void CommandModule::saveCommand()
     }
     else if (commandType == 3)
     {
-        // Keyword
+        item->setData(Qt::UserRole + 4,
+                      this->keywordListWidget->getItemsFromList());
     }
     else if (commandType == 4)
     {
@@ -595,9 +650,9 @@ void CommandModule::syncCommands()
         {
             commandMap.insert("filename", item->data(Qt::UserRole + 4));
         }
-        else if (commandType == 3)
+        else if (commandType == 3) // A list of key:value pairs
         {
-            // Keyword
+            commandMap.insert("keywords", item->data(Qt::UserRole + 4));
         }
         else if (commandType == 4) // A program to run
         {
@@ -618,7 +673,7 @@ void CommandModule::syncCommands()
     this->commandHandler->setCommandData(commandDataList);
     this->dataFile->saveData(commandDataList);
 
-    this->globalObj->addToLog(tr("Saved %1 commands.")
-                              .arg(commandDataList.length()));
+    this->globalObj->addToLog(tr("Saved %Ln command(s).", "",
+                              commandDataList.length()));
 }
 
