@@ -28,6 +28,7 @@
 #include <QFormLayout>
 #include <QTabWidget>
 #include <QCheckBox>
+#include <QSpinBox>
 #include <QPushButton>
 #include <QAction>
 #include <QSettings>
@@ -63,12 +64,14 @@ private:
     QWidget *generalOptionsWidget;
     QFormLayout *generalOptionsLayout;
     StringListWidget *adminJidListWidget;
+    QLineEdit *commandPrefixLineEdit;
+    QSpinBox *keepAliveSpinbox;
 
 
     QWidget *notificationOptionsWidget;
     QFormLayout *notificationOptionsLayout;
     QCheckBox *notifyNewChatsCheckbox;
-    QLineEdit *commandPrefixLineEdit;
+    QCheckBox *notifyDisconnectionCheckbox;
 
 
     QWidget *systrayOptionsWidget;
