@@ -39,6 +39,12 @@ public:
     static QString nickFromRoomJid(QString jid);
     static QString safeForHtml(QString text);
 
+    static QString randomString(QStringList stringList);
+    static int randomBetween(int lowNum, int highNum);
+    static bool probability(int chancePercent);
+
+
+
 
 signals:
 
