@@ -27,6 +27,9 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     this->setWindowIcon(QIcon(":/icon/64x64/akarixb.png"));
     this->setMinimumSize(500, 400);
 
+    // Ensure closing a dialog while the main window is hidden, won't end the program
+    qApp->setQuitOnLastWindowClosed(false);
+
     this->globalObject = new GlobalObject(this);
     connect(globalObject, SIGNAL(showInStatusBar(QString)),
             this, SLOT(setStatusBarMessage(QString)));
@@ -38,7 +41,16 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     setupXmppClient();
 
-    // Page 7, runtime log, needed before others for early logging
+    // It's important to initialize this before creating the handlers, which use it
+    this->variableParser = new VariableParser(this);
+    this->globalObject->setVariableParser(variableParser);
+
+    this->messageHandler = new MessageHandler(globalObject, this);
+    this->commandHandler = new CommandHandler(globalObject, this);
+    this->activityHandler = new ActivityHandler(globalObject, this);
+
+
+    // Page 8, runtime log, needed before others for early logging
     this->logModule = new LogModule(this);
     connect(globalObject, SIGNAL(logMessage(QString)),
             logModule, SLOT(addToLog(QString)));
@@ -71,8 +83,12 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     this->conversationModule = new ConversationModule(this);
 
     // Page 6, activities
-    this->activityModule = new ActivityModule(this->globalObject, this);
+    this->activityModule = new ActivityModule(this->activityHandler,
+                                              this->globalObject,
+                                              this);
 
+    // Page 7, identity
+    this->identityModule = new IdentityModule(this->globalObject, this);
 
 
 
@@ -106,8 +122,11 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     categoriesList->addItem(tr("Activities"));
     categoriesList->item(5)->setIcon(QIcon::fromTheme("view-categories",
                                                       QIcon(":/images/section-general.png")));
+    categoriesList->addItem(tr("Identity"));
+    categoriesList->item(6)->setIcon(QIcon::fromTheme("user-identity",
+                                                      QIcon(":/images/no-avatar.png")));
     categoriesList->addItem(tr("Log"));
-    categoriesList->item(6)->setIcon(QIcon::fromTheme("text-x-log",
+    categoriesList->item(7)->setIcon(QIcon::fromTheme("text-x-log",
                                                       QIcon(":/images/section-log.png")));
 
     // Pages on right side
@@ -118,6 +137,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     stackedWidget->addWidget(commandModule);
     stackedWidget->addWidget(conversationModule);
     stackedWidget->addWidget(activityModule);
+    stackedWidget->addWidget(identityModule);
     stackedWidget->addWidget(logModule);
     connect(categoriesList, SIGNAL(currentRowChanged(int)),
             stackedWidget, SLOT(setCurrentIndex(int)));
@@ -304,6 +324,10 @@ void MainWindow::createTrayIcon()
         connect(systrayIcon, SIGNAL(messageClicked()),
                 this, SLOT(show()));  // FIXME: this can mess up the first action in the context menu
 
+        // Show notifications requested via GlobalObject
+        connect(globalObject, SIGNAL(showNotificationPopup(QString,QString)),
+                this, SLOT(showNotification(QString,QString)));
+
         // Set contextual menu for the icon
         systrayIcon->setContextMenu(systrayMenu);
         systrayIcon->setToolTip("AkariXB");
@@ -386,8 +410,13 @@ void MainWindow::createDataDir()
 void MainWindow::setupXmppClient()
 {
     this->xmppClient = new QXmppClient(this);
+    xmppClient->configuration().setKeepAliveTimeout(this->globalObject->getKeepAliveTimeout());
     xmppClient->versionManager().setClientOs("Akari-GNU-OS"); // tmp FIXME xD
 
+#if 0  // Verbose XMPP console
+    xmppClient->logger()->setLoggingType(QXmppLogger::StdoutLogging);
+#endif
+
     connect(xmppClient, SIGNAL(connected()),
             this, SLOT(onConnected()));
     connect(xmppClient, SIGNAL(disconnected()),
@@ -399,6 +428,9 @@ void MainWindow::setupXmppClient()
     connect(xmppClient, SIGNAL(presenceReceived(QXmppPresence)),
             this, SLOT(processPresence(QXmppPresence)));
 
+    connect(xmppClient, SIGNAL(iqReceived(QXmppIq)),
+            this, SLOT(processIq(QXmppIq)));
+
     connect(xmppClient, SIGNAL(error(QXmppClient::Error)),
             this, SLOT(onNetworkError(QXmppClient::Error)));
 
@@ -408,9 +440,6 @@ void MainWindow::setupXmppClient()
 
     this->globalObject->setXmppClient(this->xmppClient);
     this->globalObject->setMucManager(this->mucManager);
-
-    this->messageHandler = new MessageHandler(globalObject, this);
-    this->commandHandler = new CommandHandler(globalObject, this);
 }
 
 
@@ -513,13 +542,19 @@ void MainWindow::onConnected()
     this->generalModule->setInfoMessage(message);
     this->globalObject->addToLog(message);
 
+    QStringList statusMessages;    // TMP hardcoded 'default' messages
+    statusMessages << "H{i|ii|iii}!"
+                   << "I'm h{e|ee|eee}re{!|!!}"
+                   << "%ownnick% is here{!|!!|!!!}"
+                   << "I'm around...";
 
     QXmppPresence presence;
     presence.setPriority(this->userPriority);
-    presence.setAvailableStatusType(QXmppPresence::Chat); // TMP presence tests
-    presence.setStatusText("Testing status message!");
+    presence.setAvailableStatusType(QXmppPresence::Online);
+    presence.setStatusText(this->variableParser->getParsed(Helpers::randomString(statusMessages)));
     this->xmppClient->setClientPresence(presence);
 
+    this->sessionConnectAction->setDisabled(true); // Need to disable this here again, for auto-reconnections
     this->sessionDisconnectAction->setEnabled(true);
 
     this->roomModule->autojoinRooms();
@@ -542,6 +577,15 @@ void MainWindow::onDisconnected()
     this->globalObject->setConnected(false);
     this->setTitleAndTrayInfo();
     this->setStatusIconOnline(false);
+
+    if (globalObject->getNotifyDisconnection())
+    {
+        // FIXME: don't show notification if disconnection is manual
+        globalObject->showNotification(tr("Disconnected"),
+                                       tr("Connection to the server was lost."));
+    }
+
+    // TODO: optional email notification for this event
 }
 
 
@@ -561,8 +605,16 @@ void MainWindow::processMessage(QXmppMessage message)
     if (message.type() == QXmppMessage::Chat
      || message.type() == QXmppMessage::Normal)
     {
-        this->chatModule->addChatTab(message);
+        // Ignore completely empty messages (from ChatState changes, etc)
+        // FIXME: In the future, show these state changes somewhere else
+        if (!message.body().isEmpty())
+        {
+            this->chatModule->addChatTab(message);
+        }
     }
+
+    //qDebug() << "processMessage() " << message.error().text()
+    //             << message.error().code();
 }
 
 
@@ -572,6 +624,15 @@ void MainWindow::processPresence(QXmppPresence presence)
 }
 
 
+void MainWindow::processIq(QXmppIq iq)
+{
+    qDebug() << "IQ received:" << iq.from() << iq.type();
+
+    // This causes crashes sometimes
+    //qDebug() << iq.extensions().first().tagName();
+}
+
+
 
 void MainWindow::onNetworkError(QXmppClient::Error error)
 {
@@ -597,6 +658,10 @@ void MainWindow::onNetworkError(QXmppClient::Error error)
 
     QString message = tr("Network error: %1").arg(errorString);
     this->globalObject->addToLog(message);
+
+    //qDebug() << "Network error:"
+    //         << "\nStanza:" << this->xmppClient->xmppStreamError()
+    //         << "\nSocket:" << this->xmppClient->socketErrorString();
 }
 
 
@@ -679,15 +744,11 @@ void MainWindow::aboutAkariXB()
                          "<br><br>"
                          "<a href=\"https://techbase.kde.org/Projects/Oxygen\">"
                          "techbase.kde.org/Projects/Oxygen</a>"
-                         "<br>");
+                         "<br>"
+                         "<br>"
 
-    // FIXME: ugly workaround to avoid closing the program after closing
-    if (this->isHidden()) // the About dialog, if the main window was hidden
-    {
-        this->show();
-        this->hide();
-        qDebug() << "MainWindow was hidden, showing and hiding again";
-    }
+                       + QString("<b>Qt</b> v%1").arg(qVersion())
+                       + "<br>");
 }
 
 
@@ -758,6 +819,17 @@ void MainWindow::setStatusBarMessage(QString message)
 }
 
 
+void MainWindow::showNotification(QString title, QString message)
+{
+    if (/*trayIconAvailable*/true) // FIXME
+    {
+        this->systrayIcon->showMessage(title, message,
+                                       QSystemTrayIcon::Information, // FIXME, make variable
+                                       10000); // 10 secs
+    }
+}
+
+
 /*
  * Control interaction with the system tray icon
  *
@@ -809,6 +881,8 @@ void MainWindow::quitProgram()
         this->show();
     }
 
+    qApp->setQuitOnLastWindowClosed(true);
+
     std::cout << "\nShutting down AkariXB (" + this->userJid.toStdString()
                  + ")...\n";
     std::cout.flush();
