@@ -32,6 +32,7 @@
 
 
 #include "globalobject.h"
+#include "variableparser.h"
 
 
 class MessageHandler : public QObject
@@ -56,6 +57,7 @@ private:
     QXmppMucManager *mucManager;
 
     GlobalObject *globalObj;
+    VariableParser *varParser;
 };
 
 #endif // MESSAGEHANDLER_H
