@@ -78,9 +78,34 @@ RoomModule::RoomModule(GlobalObject *globalObject,
     connect(roomJidLineEdit, SIGNAL(returnPressed()),
             nickLineEdit, SLOT(setFocus()));
 
+    this->roomPasswordLineEdit = new QLineEdit(this);
+    roomPasswordLineEdit->setPlaceholderText(tr("Password, if needed"));
+    roomPasswordLineEdit->setEchoMode(QLineEdit::Password);
+    connect(nickLineEdit, SIGNAL(returnPressed()),
+            roomPasswordLineEdit, SLOT(setFocus()));
+
     this->autojoinCheckbox = new QCheckBox(tr("Autojoin"), this);
 
 
+    // Edit / Update
+    this->editRoomButton = new QPushButton(QIcon::fromTheme("document-edit",
+                                                            QIcon(":/images/button-edit.png")),
+                                           tr("&Edit"),
+                                           this);
+    editRoomButton->setDisabled(true);
+    connect(editRoomButton, SIGNAL(clicked()),
+            this, SLOT(editRoom()));
+
+    this->updateRoomButton = new QPushButton(QIcon::fromTheme("view-refresh",
+                                                              QIcon(":/images/button-refresh.png")),
+                                             tr("&Update"),
+                                             this);
+    connect(updateRoomButton, SIGNAL(clicked()),
+            this, SLOT(updateRoom()));
+    connect(roomPasswordLineEdit, SIGNAL(returnPressed()),
+            updateRoomButton, SLOT(setFocus()));
+
+    // Join / Leave
     this->joinButton = new QPushButton(QIcon::fromTheme("list-add",
                                                         QIcon(":/images/list-add.png")),
                                        tr("Join"),
@@ -98,22 +123,6 @@ RoomModule::RoomModule(GlobalObject *globalObject,
             this, SLOT(leaveSelectedRoom()));
 
 
-    this->editRoomButton = new QPushButton(QIcon::fromTheme("document-edit",
-                                                            QIcon(":/images/button-edit.png")),
-                                           tr("&Edit"),
-                                           this);
-    editRoomButton->setDisabled(true);
-    connect(editRoomButton, SIGNAL(clicked()),
-            this, SLOT(editRoom()));
-
-    this->updateRoomButton = new QPushButton(QIcon::fromTheme("view-refresh",
-                                                              QIcon(":/images/button-refresh.png")),
-                                             tr("&Update"),
-                                             this);
-    connect(updateRoomButton, SIGNAL(clicked()),
-            this, SLOT(updateRoom()));
-    connect(nickLineEdit, SIGNAL(returnPressed()),
-            updateRoomButton, SLOT(setFocus()));
 
 
     // Stacked widget to hold ChatWidgets
@@ -128,15 +137,16 @@ RoomModule::RoomModule(GlobalObject *globalObject,
 
 
     this->detailsUpperLayout = new QHBoxLayout();
-    detailsUpperLayout->addWidget(roomJidLineEdit, 3);
-    detailsUpperLayout->addWidget(nickLineEdit,    2);
+    detailsUpperLayout->addWidget(roomJidLineEdit,      3);
+    detailsUpperLayout->addWidget(nickLineEdit,         2);
+    detailsUpperLayout->addWidget(roomPasswordLineEdit, 2);
     detailsUpperLayout->addWidget(autojoinCheckbox);
     detailsUpperLayout->addStretch();
     detailsUpperLayout->addSpacing(8);
-    detailsUpperLayout->addWidget(joinButton);
-    detailsUpperLayout->addWidget(leaveButton);
     detailsUpperLayout->addWidget(editRoomButton);
     detailsUpperLayout->addWidget(updateRoomButton);
+    detailsUpperLayout->addWidget(joinButton);
+    detailsUpperLayout->addWidget(leaveButton);
 
 
     this->detailsLayout = new QVBoxLayout();
@@ -181,9 +191,12 @@ void RoomModule::loadRoomInfo()
 
         QString roomJid = map.value("jid").toString();
         QString roomNickname = map.value("nickname").toString();
+        QString roomPassword = QByteArray::fromBase64(map.value("password")
+                                                         .toByteArray());
         bool roomAutojoin = map.value("autojoin").toBool();
         QString itemString = this->roomDescriptionLine(roomJid,
                                                        roomNickname,
+                                                       !roomPassword.isEmpty(),
                                                        roomAutojoin);
 
         QListWidgetItem *item = new QListWidgetItem(QIcon::fromTheme("user-offline",
@@ -191,14 +204,16 @@ void RoomModule::loadRoomInfo()
                                                     itemString);
         item->setData(Qt::UserRole,     roomJid);
         item->setData(Qt::UserRole + 1, roomNickname);
-        item->setData(Qt::UserRole + 2, roomAutojoin);
-        item->setData(Qt::UserRole + 3, false); // Joined status, initially false
+        item->setData(Qt::UserRole + 2, roomPassword);
+        item->setData(Qt::UserRole + 3, roomAutojoin);
+        item->setData(Qt::UserRole + 4, false); // Joined status, initially false
 
         roomListWidget->addItem(item);
     }
 
-    this->globalObj->addToLog(tr("Loaded %1 rooms.")
-                              .arg(roomDataList.length()));
+    this->globalObj->addToLog(tr("Loaded %Ln room(s).",
+                                 "",
+                                 roomDataList.length()));
 }
 
 
@@ -210,27 +225,46 @@ void RoomModule::saveRoomInfo()
     {
         QListWidgetItem *item = roomListWidget->item(counter);
 
-        QVariantMap roomMap;
-        roomMap.insert("jid",        item->data(Qt::UserRole).toString());
-        roomMap.insert("nickname",   item->data(Qt::UserRole + 1).toString());
-        roomMap.insert("autojoin",   item->data(Qt::UserRole + 2).toBool());
+        QString roomJid = item->data(Qt::UserRole).toString().trimmed();
+        QString roomNick = item->data(Qt::UserRole + 1).toString().trimmed();
 
-        roomDataList.append(roomMap);
+        // Don't save data for invalid rooms
+        if (Helpers::isValidJid(roomJid) && !roomNick.isEmpty())
+        {
+            QVariantMap roomMap;
+            roomMap.insert("jid",        roomJid);
+            roomMap.insert("nickname",   roomNick);
+            roomMap.insert("password",   item->data(Qt::UserRole + 2).toByteArray()
+                                                                     .toBase64());
+            roomMap.insert("autojoin",   item->data(Qt::UserRole + 3).toBool());
+
+            roomDataList.append(roomMap);
+        }
     }
 
     this->dataFile->saveData(roomDataList);
 
     // FIXME: This might lead to segfault when called while quitting
-    //this->globalObj->addToLog(tr("Saved %1 rooms.")
-    //                          .arg(roomDataList.length()));
+    //this->globalObj->addToLog(tr("Saved %Ln room(s).", "",
+    //                             roomDataList.length()));
 }
 
 
 
 QString RoomModule::roomDescriptionLine(QString roomJid, QString nickname,
-                                        bool autojoin)
+                                        bool hasPassword, bool autojoin)
 {
+    // FiXME: this list needs to be converted into a proper table
     QString description = tr("%1 as %2").arg(roomJid).arg(nickname);
+
+    if (hasPassword)
+    {
+        description.append(QString::fromUtf8("              \342\232\277  ") // Squared key
+                           + "("
+                           + tr("Password")
+                           + ")");
+    }
+
     if (autojoin)
     {
         description.append(QString::fromUtf8("              \342\234\224  ") // Check mark
@@ -263,19 +297,6 @@ QListWidgetItem *RoomModule::listItemFromJid(QString roomJid)
 }
 
 
-QXmppMucRoom *RoomModule::roomFromJid(QString roomJid)
-{
-    foreach (QXmppMucRoom *room, mucManager->rooms())
-    {
-        if (room->jid() == roomJid)
-        {
-            return room;
-        }
-    }
-
-    return 0;
-}
-
 
 /*
  * Get the page number in the QStackedWidget that matches
@@ -300,16 +321,22 @@ int RoomModule::stackIndexFromJid(QString roomJid)
 
 
 
-void RoomModule::joinRoom(QString roomJid, QString nickname)
+void RoomModule::joinRoom(QString roomJid, QString nickname, QString password)
 {
     QXmppMucRoom *room = mucManager->addRoom(roomJid);
     room->setNickName(nickname);
+    if (!password.isEmpty())
+    {
+        room->setPassword(password);
+    }
+
     room->join();
 
-    QString message = tr("Joining room %1...").arg(room->jid());
 
+    QString message = tr("Joining room %1...").arg(room->jid());
     this->globalObj->addToLog(message);
 
+
     ChatWidget *newChatWidget = new ChatWidget(this->globalObj, this);
     newChatWidget->setRoom(room);
     connect(newChatWidget, SIGNAL(roomJoined(QString)),
@@ -327,7 +354,7 @@ void RoomModule::joinRoom(QString roomJid, QString nickname)
 
 void RoomModule::leaveRoom(QString roomJid, QString reason)
 {
-    QXmppMucRoom *room = this->roomFromJid(roomJid);
+    QXmppMucRoom *room = this->globalObj->roomFromJid(roomJid);
     if (room)
     {
         QString message = tr("Leaving room %1...").arg(room->jid());
@@ -350,7 +377,7 @@ void RoomModule::leaveRoom(QString roomJid, QString reason)
 
         QListWidgetItem *item = this->listItemFromJid(roomJid);
         // These item modifications should be handled from onRoomLeft() - FIXME?
-        item->setData(Qt::UserRole + 3, false); // Set as not-joined
+        item->setData(Qt::UserRole + 4, false); // Set as not-joined
         item->setIcon(QIcon::fromTheme("user-offline",
                                        QIcon(":/images/button-offline.png")));
         this->showRoomDetails(item);
@@ -373,23 +400,28 @@ void RoomModule::autojoinRooms()
 
         QString roomJid = item->data(Qt::UserRole).toString();
         QString roomNick = item->data(Qt::UserRole + 1).toString();
+        QString roomPass = item->data(Qt::UserRole + 2).toString();
 
-        if (item->data(Qt::UserRole + 2).toBool()                // autojoin=true
+        if (item->data(Qt::UserRole + 3).toBool()                // autojoin=true
          || this->globalObj->getJoinedRooms().contains(roomJid)) // or previously joined
         {
-            this->joinRoom(roomJid, roomNick);
+            this->joinRoom(roomJid, roomNick, roomPass);
         }
     }
 }
 
 
-bool RoomModule::newRoomIsValid()
+bool RoomModule::newRoomIsValid(bool showErrors)
 {
     QString roomJid = this->roomJidLineEdit->text().trimmed();
     if (!Helpers::isValidJid(roomJid))
     {
-        QMessageBox::warning(this, tr("Error"),
-                             tr("Room address is not valid."));
+        if (showErrors)
+        {
+            QMessageBox::warning(this, tr("Error"),
+                                 tr("Room address is not valid."));
+        }
+
         this->roomJidLineEdit->setFocus();
 
         return false;
@@ -397,8 +429,12 @@ bool RoomModule::newRoomIsValid()
 
     if (this->nickLineEdit->text().trimmed().isEmpty())
     {
-        QMessageBox::warning(this, tr("Error"),
-                             tr("Nickname is not valid."));
+        if (showErrors)
+        {
+            QMessageBox::warning(this, tr("Error"),
+                                 tr("Nickname is not valid."));
+        }
+
         this->nickLineEdit->setFocus();
 
         return false;
@@ -410,8 +446,8 @@ bool RoomModule::newRoomIsValid()
 
 void RoomModule::toggleJoinLeaveButtons(QListWidgetItem *item)
 {
-    // UserRole+3 contains true if joined
-    if (item->data(Qt::UserRole + 3).toBool())
+    // UserRole+4 contains true if joined
+    if (item->data(Qt::UserRole + 4).toBool())
     {
         this->joinButton->hide();
         this->leaveButton->show();
@@ -440,6 +476,7 @@ void RoomModule::addRoom()
 
     this->roomJidLineEdit->clear();
     this->nickLineEdit->clear();
+    this->roomPasswordLineEdit->clear();
     this->autojoinCheckbox->setChecked(false);
 
     this->editRoom();
@@ -466,17 +503,19 @@ void RoomModule::updateRoom()
 
     QString roomJid = roomJidLineEdit->text().trimmed();
     QString roomNickname = nickLineEdit->text().trimmed();
+    QString roomPassword = roomPasswordLineEdit->text();
     bool roomAutojoin = autojoinCheckbox->isChecked();
 
-    if (newRoomIsValid())
+    if (newRoomIsValid(true)) // Showing errors = true
     {
         QListWidgetItem *item = this->roomListWidget->currentItem();
 
         QString itemString = this->roomDescriptionLine(roomJid,
                                                        roomNickname,
+                                                       !roomPassword.isEmpty(),
                                                        roomAutojoin);
         // Icon depends on current joined status
-        if (item->data(Qt::UserRole + 3).toBool())
+        if (item->data(Qt::UserRole + 4).toBool())
         {
             item->setIcon(QIcon::fromTheme("user-online",
                                            QIcon(":/images/button-online.png")));
@@ -490,7 +529,8 @@ void RoomModule::updateRoom()
         item->setText(itemString);
         item->setData(Qt::UserRole,     roomJid);
         item->setData(Qt::UserRole + 1, roomNickname);
-        item->setData(Qt::UserRole + 2, roomAutojoin);
+        item->setData(Qt::UserRole + 2, roomPassword);
+        item->setData(Qt::UserRole + 3, roomAutojoin);
 
         this->toggleRoomDetails(false);
     }
@@ -514,7 +554,8 @@ void RoomModule::removeRoom()
 void RoomModule::joinSelectedRoom()
 {
     this->joinRoom(this->roomJidLineEdit->text().trimmed(),
-                   this->nickLineEdit->text().trimmed());
+                   this->nickLineEdit->text().trimmed(),
+                   this->roomPasswordLineEdit->text());
 
 
     QListWidgetItem *item = this->roomListWidget->currentItem();
@@ -539,7 +580,7 @@ void RoomModule::leaveSelectedRoom()
 
 void RoomModule::changeNick()
 {
-    QXmppMucRoom *room = this->roomFromJid(this->roomJidLineEdit->text());
+    QXmppMucRoom *room = this->globalObj->roomFromJid(this->roomJidLineEdit->text());
     if (room)
     {
         room->setNickName(this->nickLineEdit->text().trimmed());
@@ -553,7 +594,8 @@ void RoomModule::showRoomDetails(QListWidgetItem *item)
     //qDebug() << "showRoomDetails()" << item->data(Qt::UserRole).toString();
     this->roomJidLineEdit->setText(item->data(Qt::UserRole).toString());
     this->nickLineEdit->setText(item->data(Qt::UserRole + 1).toString());
-    this->autojoinCheckbox->setChecked(item->data(Qt::UserRole + 2).toBool());
+    this->roomPasswordLineEdit->setText(item->data(Qt::UserRole + 2).toString());
+    this->autojoinCheckbox->setChecked(item->data(Qt::UserRole + 3).toBool());
 
     this->toggleRoomDetails(false);
 
@@ -573,13 +615,17 @@ void RoomModule::toggleRoomDetails(bool state)
 {
     this->roomJidLineEdit->setEnabled(state);
     this->nickLineEdit->setEnabled(state);
+    this->roomPasswordLineEdit->setEnabled(state);
     this->autojoinCheckbox->setEnabled(state);
 
     this->updateRoomButton->setVisible(state);
     this->editRoomButton->setHidden(state); // Reversed state!
 
 
-    this->joinButton->setEnabled(globalObj->connectedToServer());
+    // Ensure join button isn't available for invalid rooms, of when offline
+    this->joinButton->setEnabled(globalObj->connectedToServer()
+                              && newRoomIsValid());
+
     this->leaveButton->setEnabled(globalObj->connectedToServer());
 
 
@@ -603,7 +649,7 @@ void RoomModule::onRoomJoined(QString jid)
         item->setIcon(QIcon::fromTheme("user-online",
                                        QIcon(":/images/button-online.png")));
 
-        item->setData(Qt::UserRole + 3, true); // Mark as joined
+        item->setData(Qt::UserRole + 4, true); // Mark as joined
 
         if (item->isSelected())
         {
