@@ -1,6 +1,38 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="ca_ES">
+<context>
+    <name>ActivityHandler</name>
+    <message>
+        <source>Starting activity %1, which will end at %2.</source>
+        <translation>Començant activitat %1, que acabarà a les %2.</translation>
+    </message>
+    <message>
+        <source>Activity ended: %1.</source>
+        <translation>Activitat finalitzada: %1.</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <comment>Regarding an activity</comment>
+        <translation>Cap</translation>
+    </message>
+    <message numerus="yes">
+        <source>%Ln hour(s)</source>
+        <translation>
+            <numerusform>1 hora</numerusform>
+            <numerusform>%Ln hores</numerusform>
+            <numerusform>%Ln hores</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%Ln minute(s)</source>
+        <translation>
+            <numerusform>1 minut</numerusform>
+            <numerusform>%Ln minuts</numerusform>
+            <numerusform>%Ln minuts</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>ActivityModule</name>
     <message>
@@ -33,11 +65,11 @@
     </message>
     <message>
         <source>seconds</source>
-        <translation type="unfinished">segons</translation>
+        <translation>segons</translation>
     </message>
     <message>
         <source>All rooms</source>
-        <translation type="unfinished"></translation>
+        <translation>Totes les sales</translation>
     </message>
     <message>
         <source>Several rooms</source>
@@ -97,11 +129,11 @@
     </message>
     <message>
         <source>Messages Before</source>
-        <translation type="unfinished"></translation>
+        <translation>Missatges abans</translation>
     </message>
     <message>
         <source>Send Messages To</source>
-        <translation type="unfinished"></translation>
+        <translation>Enviar missatges a</translation>
     </message>
     <message>
         <source>&amp;Sync Activities</source>
@@ -113,11 +145,7 @@
     </message>
     <message>
         <source>Messages Afterwards</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Loaded %1 activities.</source>
-        <translation type="unfinished"></translation>
+        <translation>Missatges després</translation>
     </message>
     <message>
         <source>New Activity</source>
@@ -125,16 +153,40 @@
     </message>
     <message>
         <source>Activity exists</source>
-        <translation type="unfinished"></translation>
+        <translation>L&apos;activitat existeix</translation>
     </message>
     <message>
         <source>Error: There is already an activity in the list with this name.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Saved %1 activities.</source>
+        <source>Specific JIDs</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>List of room or user addresses, separated by space</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Status Messages</source>
+        <translation>Missatges d&apos;estat</translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved %Ln activities.</source>
+        <translation>
+            <numerusform>S&apos;ha guardat 1 activitat.</numerusform>
+            <numerusform>S&apos;han guardat %Ln activitats.</numerusform>
+            <numerusform>S&apos;han guardat %Ln activitats.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Loaded %Ln activities.</source>
+        <translation>
+            <numerusform>S&apos;ha carregat 1 activitat.</numerusform>
+            <numerusform>S&apos;han carregat %Ln activitats.</numerusform>
+            <numerusform>S&apos;han carregat %Ln activitats.</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>ChatModule</name>
@@ -143,12 +195,20 @@
         <comment>%1 = A nickname</comment>
         <translation>Conversa iniciada per %1.</translation>
     </message>
+    <message>
+        <source>New chat</source>
+        <translation type="unfinished">Nova conversa</translation>
+    </message>
+    <message>
+        <source>A new chat was started by %1.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChatWidget</name>
     <message>
         <source>Reason:</source>
-        <translation type="unfinished">Motiu:</translation>
+        <translation>Motiu:</translation>
     </message>
     <message>
         <source>Kicked from the room!</source>
@@ -177,10 +237,6 @@
         <source>The command failed.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Available commands:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Error loading file %1 for command: %2</source>
         <translation type="unfinished"></translation>
@@ -189,6 +245,34 @@
         <source>Command gave no output text.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>I don&apos;t have help about: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Help for %1:</source>
+        <translation type="unfinished">Ajuda de %1:</translation>
+    </message>
+    <message>
+        <source>Available commands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Command %1 requested without the right access level.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>I need a parameter for the query.</source>
+        <translation type="unfinished">Necessito un paràmetre per la consulta.</translation>
+    </message>
+    <message>
+        <source>I don&apos;t have a match for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This command is an alias to itself!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CommandModule</name>
@@ -204,10 +288,6 @@
         <source>Random Sentence</source>
         <translation type="unfinished">Frase aleatòria</translation>
     </message>
-    <message>
-        <source>Keyword</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Save &amp;Command</source>
         <translation type="unfinished"></translation>
@@ -257,10 +337,6 @@
         <source>Select File...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Loaded %1 commands.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Static reply is empty.</source>
         <translation type="unfinished"></translation>
@@ -310,8 +386,72 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Saved %1 commands.</source>
-        <translation type="unfinished">S&apos;han guardat %1 ordres.</translation>
+        <source>Just enter a single sentence.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add as many sentences as you want.
+One of them will be selected at random as a reply.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A random line from the chosen file will be used as a reply.
+File encoding should be UTF-8.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keyword-based Message</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add keywords to the list, then enter the corresponding definition for each keyword on the other side.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter a command to be run, with any needed parameters.
+The reply will be the console output of the program, unless you specify an output pattern, and don&apos;t include the %output% variable somewhere in it.</source>
+        <comment>Don&apos;t translate %output%!</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter the original command that should be run when this alias is used.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Optional, like: [RESULT] %line% %output%</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Output Pattern</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Private Reply</source>
+        <translation type="unfinished">Resposta privada</translation>
+    </message>
+    <message>
+        <source>There are no keywords in the list.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A command can&apos;t be an alias of itself.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>Loaded %Ln command(s).</source>
+        <translation>
+            <numerusform>S&apos;ha carregat 1 ordre.</numerusform>
+            <numerusform>S&apos;han carregat %Ln ordres.</numerusform>
+            <numerusform>S&apos;han carregat %Ln ordres.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved %Ln command(s).</source>
+        <translation>
+            <numerusform>S&apos;ha guardat 1 ordre.</numerusform>
+            <numerusform>S&apos;han guardat %Ln ordres.</numerusform>
+            <numerusform>S&apos;han guardat %Ln ordres.</numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -330,15 +470,15 @@
     </message>
     <message>
         <source>Administrator JIDs</source>
-        <translation type="unfinished">JIDs administradors</translation>
+        <translation>JIDs administradors</translation>
     </message>
     <message>
         <source>Command prefix</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Prefix d&apos;ordres</translation>
     </message>
     <message>
         <source>Notify new chats</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Notificar de noves converses</translation>
     </message>
     <message>
         <source>Hide window on startup</source>
@@ -356,6 +496,19 @@
         <source>Cancel</source>
         <translation>Cancel·lar</translation>
     </message>
+    <message>
+        <source>seconds</source>
+        <comment>Suffix next to a number</comment>
+        <translation>segons</translation>
+    </message>
+    <message>
+        <source>Connection timeout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Notify disconnection</source>
+        <translation>Notificar desconnexió</translation>
+    </message>
 </context>
 <context>
     <name>ConnectionDialog</name>
@@ -410,6 +563,35 @@
         <source>Disconnect</source>
         <translation>Desconnectar</translation>
     </message>
+    <message>
+        <source>Current Activity:</source>
+        <translation>Activitat actual:</translation>
+    </message>
+    <message>
+        <source>Status Message:</source>
+        <translation>Missatge d&apos;estat:</translation>
+    </message>
+</context>
+<context>
+    <name>IdentityModule</name>
+    <message>
+        <source>&amp;Update</source>
+        <translation>&amp;Actualitzar</translation>
+    </message>
+    <message>
+        <source>Nickname</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Loaded identity data for %1.</source>
+        <comment>%1 is a nickname</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Saved identity data for %1.</source>
+        <comment>%1 is a nickname</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogModule</name>
@@ -541,12 +723,52 @@
         <source>Data directory in use: %1</source>
         <translation>Directori de dades en ús: %1</translation>
     </message>
+    <message>
+        <source>Identity</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ready.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Session</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>S&amp;ettings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Help</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection to the server was lost.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Socket Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>KeepAlive Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>XMPP Stream Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
     <message>
         <source>Error %1 from %2: %3</source>
-        <translation type="unfinished">Error %1 de %2: %3</translation>
+        <translation>Error %1 de %2: %3</translation>
     </message>
 </context>
 <context>
@@ -623,6 +845,22 @@
         <source>Joining room %1...</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Password, if needed</source>
+        <translation type="unfinished">Contrasenya, si cal</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished">Contrasenya</translation>
+    </message>
+    <message numerus="yes">
+        <source>Loaded %Ln room(s).</source>
+        <translation>
+            <numerusform>S&apos;ha carregat 1 sala.</numerusform>
+            <numerusform>S&apos;han carregat %Ln sales.</numerusform>
+            <numerusform>S&apos;han carregat %Ln sales.</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>StringListWidget</name>
@@ -634,5 +872,9 @@
         <source>Enter a new line of text for the list</source>
         <translation>Introdueix una nova línia de text per la llista</translation>
     </message>
+    <message>
+        <source>Update the text for this item</source>
+        <translation>Actualitza el text d&apos;aquest element</translation>
+    </message>
 </context>
 </TS>
