@@ -1,6 +1,36 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="es_ES">
+<context>
+    <name>ActivityHandler</name>
+    <message>
+        <source>Starting activity %1, which will end at %2.</source>
+        <translation>Comenzando actividad %1, que acabará a las %2.</translation>
+    </message>
+    <message>
+        <source>Activity ended: %1.</source>
+        <translation>Actividad finalizada: %1.</translation>
+    </message>
+    <message>
+        <source>None</source>
+        <comment>Regarding an activity</comment>
+        <translation>Ninguna</translation>
+    </message>
+    <message numerus="yes">
+        <source>%Ln hour(s)</source>
+        <translation>
+            <numerusform>1 hora</numerusform>
+            <numerusform>%Ln horas</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%Ln minute(s)</source>
+        <translation>
+            <numerusform>1 minuto</numerusform>
+            <numerusform>%Ln minutos</numerusform>
+        </translation>
+    </message>
+</context>
 <context>
     <name>ActivityModule</name>
     <message>
@@ -33,11 +63,11 @@
     </message>
     <message>
         <source>seconds</source>
-        <translation type="unfinished">segundos</translation>
+        <translation>segundos</translation>
     </message>
     <message>
         <source>All rooms</source>
-        <translation type="unfinished"></translation>
+        <translation>Todas las salas</translation>
     </message>
     <message>
         <source>Several rooms</source>
@@ -97,11 +127,11 @@
     </message>
     <message>
         <source>Messages Before</source>
-        <translation type="unfinished"></translation>
+        <translation>Mensajes antes</translation>
     </message>
     <message>
         <source>Send Messages To</source>
-        <translation type="unfinished"></translation>
+        <translation>Enviar mensajes a</translation>
     </message>
     <message>
         <source>&amp;Sync Activities</source>
@@ -113,11 +143,7 @@
     </message>
     <message>
         <source>Messages Afterwards</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Loaded %1 activities.</source>
-        <translation type="unfinished"></translation>
+        <translation>Mensajes después</translation>
     </message>
     <message>
         <source>New Activity</source>
@@ -125,16 +151,38 @@
     </message>
     <message>
         <source>Activity exists</source>
-        <translation type="unfinished"></translation>
+        <translation>La actividad existe</translation>
     </message>
     <message>
         <source>Error: There is already an activity in the list with this name.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Saved %1 activities.</source>
+        <source>Specific JIDs</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>List of room or user addresses, separated by space</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Status Messages</source>
+        <translation>Mensajes de estado</translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved %Ln activities.</source>
+        <translation>
+            <numerusform>Se ha guardado 1 actividad.</numerusform>
+            <numerusform>Se han guardado %Ln actividades.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Loaded %Ln activities.</source>
+        <translation>
+            <numerusform>Se ha cargado 1 actividad.</numerusform>
+            <numerusform>Se han cargado %Ln actividades.</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>ChatModule</name>
@@ -143,12 +191,20 @@
         <comment>%1 = A nickname</comment>
         <translation>Conversación iniciada por %1.</translation>
     </message>
+    <message>
+        <source>New chat</source>
+        <translation type="unfinished">Nueva conversación</translation>
+    </message>
+    <message>
+        <source>A new chat was started by %1.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChatWidget</name>
     <message>
         <source>Reason:</source>
-        <translation type="unfinished">Motivo:</translation>
+        <translation>Motivo:</translation>
     </message>
     <message>
         <source>Kicked from the room!</source>
@@ -177,10 +233,6 @@
         <source>The command failed.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Available commands:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Error loading file %1 for command: %2</source>
         <translation type="unfinished"></translation>
@@ -189,6 +241,34 @@
         <source>Command gave no output text.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>I don&apos;t have help about: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Help for %1:</source>
+        <translation type="unfinished">Ayuda de %1:</translation>
+    </message>
+    <message>
+        <source>Available commands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Command %1 requested without the right access level.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>I need a parameter for the query.</source>
+        <translation type="unfinished">Necesito un parámetro para la consulta.</translation>
+    </message>
+    <message>
+        <source>I don&apos;t have a match for %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This command is an alias to itself!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CommandModule</name>
@@ -204,10 +284,6 @@
         <source>Random Sentence</source>
         <translation type="unfinished">Frase aleatoria</translation>
     </message>
-    <message>
-        <source>Keyword</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Save &amp;Command</source>
         <translation type="unfinished"></translation>
@@ -257,10 +333,6 @@
         <source>Select File...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Loaded %1 commands.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Static reply is empty.</source>
         <translation type="unfinished"></translation>
@@ -310,8 +382,70 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Saved %1 commands.</source>
-        <translation type="unfinished">Se han guardado %1 comandos.</translation>
+        <source>Just enter a single sentence.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add as many sentences as you want.
+One of them will be selected at random as a reply.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A random line from the chosen file will be used as a reply.
+File encoding should be UTF-8.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Keyword-based Message</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add keywords to the list, then enter the corresponding definition for each keyword on the other side.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter a command to be run, with any needed parameters.
+The reply will be the console output of the program, unless you specify an output pattern, and don&apos;t include the %output% variable somewhere in it.</source>
+        <comment>Don&apos;t translate %output%!</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter the original command that should be run when this alias is used.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Optional, like: [RESULT] %line% %output%</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Output Pattern</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Private Reply</source>
+        <translation type="unfinished">Respuesta privada</translation>
+    </message>
+    <message>
+        <source>There are no keywords in the list.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A command can&apos;t be an alias of itself.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>Loaded %Ln command(s).</source>
+        <translation>
+            <numerusform>Se ha cargado 1 comando.</numerusform>
+            <numerusform>Se han cargado %Ln comandos.</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>Saved %Ln command(s).</source>
+        <translation>
+            <numerusform>Se ha guardado 1 comando.</numerusform>
+            <numerusform>Se han guardado %Ln comandos.</numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -330,15 +464,15 @@
     </message>
     <message>
         <source>Administrator JIDs</source>
-        <translation type="unfinished">JIDs administradores</translation>
+        <translation>JIDs administradores</translation>
     </message>
     <message>
         <source>Command prefix</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Prefijo de órdenes</translation>
     </message>
     <message>
         <source>Notify new chats</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Notificar nuevas conversaciones</translation>
     </message>
     <message>
         <source>Hide window on startup</source>
@@ -356,6 +490,19 @@
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
+    <message>
+        <source>seconds</source>
+        <comment>Suffix next to a number</comment>
+        <translation>segundos</translation>
+    </message>
+    <message>
+        <source>Connection timeout</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Notify disconnection</source>
+        <translation>Notificar desconexión</translation>
+    </message>
 </context>
 <context>
     <name>ConnectionDialog</name>
@@ -410,6 +557,35 @@
         <source>Disconnect</source>
         <translation>Desconectar</translation>
     </message>
+    <message>
+        <source>Current Activity:</source>
+        <translation>Actividad actual:</translation>
+    </message>
+    <message>
+        <source>Status Message:</source>
+        <translation>Mensaje de estado:</translation>
+    </message>
+</context>
+<context>
+    <name>IdentityModule</name>
+    <message>
+        <source>&amp;Update</source>
+        <translation>&amp;Actualizar</translation>
+    </message>
+    <message>
+        <source>Nickname</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Loaded identity data for %1.</source>
+        <comment>%1 is a nickname</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Saved identity data for %1.</source>
+        <comment>%1 is a nickname</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LogModule</name>
@@ -541,12 +717,52 @@
         <source>Data directory in use: %1</source>
         <translation>Directorio de datos en uso: %1</translation>
     </message>
+    <message>
+        <source>Identity</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ready.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Session</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>S&amp;ettings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Help</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection to the server was lost.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Socket Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>KeepAlive Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>XMPP Stream Error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
     <message>
         <source>Error %1 from %2: %3</source>
-        <translation type="unfinished">Error %1 de %2: %3</translation>
+        <translation>Error %1 de %2: %3</translation>
     </message>
 </context>
 <context>
@@ -623,6 +839,21 @@
         <source>Joining room %1...</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Password, if needed</source>
+        <translation type="unfinished">Contraseña, si se necesita</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation type="unfinished">Contraseña</translation>
+    </message>
+    <message numerus="yes">
+        <source>Loaded %Ln room(s).</source>
+        <translation>
+            <numerusform>Se ha cargado una sala.</numerusform>
+            <numerusform>Se han cargado %Ln salas.</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>StringListWidget</name>
@@ -634,5 +865,9 @@
         <source>Enter a new line of text for the list</source>
         <translation>Introduce una nueva línea de texto para la lista</translation>
     </message>
+    <message>
+        <source>Update the text for this item</source>
+        <translation>Actualiza el texto de este elemento</translation>
+    </message>
 </context>
 </TS>
